Learn R Programming

DeconRNASeq (version 1.14.0)

DeconRNASeq-package: package DeconRNASeq contains function "DeconRNASeq", implementing the decomposition of RNA-Seq expression profilings of heterogeneous tissues into cell/tissue type specific expression and cell type concentration based on cell-type-specific reference measurements.

Description

Main function "DeconRNASeq" implements an nonnegative decomposition by quadratic programming as datasets = signature*A, where "datasets" are the originally measured data matrix (e.g. genes by samples), "signature" is the signature matrix (genes by cell types) and "A" the cell type concentration matrix (cell types by samples)

Arguments

Details

Package:
DeconRNASeq
Type:
Package
Version:
1.0
Date:
2012-05-25
License:
GPL version 2 or later
DeconRNASeq(datasets, signature)

References

Gong, T., et al. (2011) Optimal Deconvolution of Transcriptional Profiling Data Using Quadratic Programming with Application to Complex Clinical Blood Samples, PLoS One, 6, e27156.