Learn R Programming

DeconRNASeq (version 1.14.0)

liver_kidney: data objects for liver and kidney mixing samples

Description

a list containing: 1) datasets:a data drame providing the RPKM of seven mixing samples. 2) proportions: a data frame providing the fractions for liver and kidney in the mixing samples

3) signatures: a data frame providing the expression values from pure liver and kidney samples

Usage

liver_kidney

Arguments

Format

A list 1) a data frame with 31979 genes' expression on the 7 mixing samples: reads.1, reads.2, reads.3, reads.4, reads.5, reads.6, reads.7 2) a martix whose rows are mixing samples' name and columns are fractions from pure live and kidney tissues 3) a data matrix with 630 expressions from pure liver and kidney tissues

Examples

Run this code
data(liver_kidney)

Run the code above in your browser using DataLab