Learn R Programming

DeconRNASeq (version 1.14.0)

multiplot: Draw the plots of proportions of cells determined from deconvolution vs. proportions of the cells actually mixed (when available) with RMSE.

Description

A function is used to draw the multiple plots of proportions of cells determined from deconvolution vs. proportions of the cells actually mixed. Each plot corresponds to one tissue/cell.

Usage

multiplot(..., plotlist = NULL, cols)

Arguments

...
any number of the plot objects that store the scatter plots for all the cells/tissue types
plotlist
any other plot objects
cols
columns of the plots, default = 1

Value

A pdf file with the plots of proportions of cells determined from deconvolution vs. proportions of the cells actually mixed with RMSE

References

Gong, T., et al. (2011) Optimal Deconvolution of Transcriptional Profiling Data Using Quadratic Programming with Application to Complex Clinical Blood Samples, PLoS One, 6, e27156.

Examples

Run this code

## The function is currently defined as
function (..., plotlist = NULL, cols) 
{
    pdf("scatterplots.pdf")
    require(grid)
    plots <- c(list(...), plotlist)
    numPlots = length(plots)
    plotCols = cols
    plotRows = ceiling(numPlots/plotCols)
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(plotRows, plotCols)))
    vplayout <- function(x, y) viewport(layout.pos.row = x, layout.pos.col = y)
    for (i in 1:numPlots) {
        curRow = ceiling(i/plotCols)
        curCol = (i - 1)%%plotCols + 1
        print(plots[[i]], vp = vplayout(curRow, curCol))
    }
    dev.off()
  }

Run the code above in your browser using DataLab