x.signature.filtered: filtered signatures for multi-tissues pure samples
Description
A data frame providing the expression values from pure brain, muscle, lung, liver and heart samples after filtering.
Usage
x.signature.filtered
Format
A martix whose rows are gene symbols and columns are RPKM expressions from pure tissues: the genes with RPKM less than 200 within any of the five tissues have been filtered.