Learn R Programming

DeconRNASeq (version 1.14.0)

x.signature.filtered.optimal: selected signatures from multi-tissues pure samples

Description

A data frame providing the expression values from pure brain, muscle, lung, liver and heart samples used for the example in DeconRNA-Seq.

Usage

x.signature.filtered.optimal

Arguments

Format

A martix whose rows are gene symbols and columns are RPKM expressions from pure tissues: based on the filtered signature matrix, the optimal number of genes have been selected for the deconvolution according to the condition numbers

Examples

Run this code
data(multi_tissue)

Run the code above in your browser using DataLab